@@ -410,9 +410,8 @@ nautilus_get_vfs_method_display_name (char *method)
 char *
 nautilus_get_uri_shortname_for_display (GnomeVFSURI *uri)
 {
-	gboolean utf8_filenames;
-	const char *filename_charset;
 	char *utf8_name, *name, *tmp;
+	char *text_uri, *local_file;
 	gboolean validated;
 	const char *method;
 
@@ -422,32 +421,12 @@ nautilus_get_uri_shortname_for_display (GnomeVFSURI *uri)
 	if (name == NULL) {
 		name = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_PASSWORD);
 	} else if (g_ascii_strcasecmp (uri->method_string, "file") == 0) {
-		utf8_filenames = eel_get_filename_charset (&filename_charset);
-		if (utf8_filenames) {
-			/* If not valid utf8, and filenames are utf8, test if converting
-			   from the locale works */
-			if (!g_utf8_validate (name, -1, NULL)) {
-				utf8_name = g_locale_to_utf8 (name, -1, NULL, NULL, NULL);
-				if (utf8_name != NULL) {
-					g_free (name);
-					name = utf8_name;
-					/* Guaranteed to be correct utf8 here */
-					validated = TRUE;
-				}
-			} else {
-				/* name was valid, no need to re-validate */
-				validated = TRUE;
-			}
-		} else {
-			/* Try to convert from filename charset to utf8 */
-			utf8_name = g_convert (name, -1, "UTF-8", filename_charset, NULL, NULL, NULL);
-			if (utf8_name != NULL) {
-				g_free (name);
-				name = utf8_name;
-				/* Guaranteed to be correct utf8 here */
-				validated = TRUE;
-			}
-		}
+		text_uri = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_PASSWORD);
+		local_file = gnome_vfs_get_local_path_from_uri (text_uri);
+		name = g_filename_display_basename (local_file);
+		g_free (local_file);
+		g_free (text_uri);
+		validated = TRUE;
 	} else if (!gnome_vfs_uri_has_parent (uri)) {
 		/* Special-case the display name for roots that are not local files */
 		method = nautilus_get_vfs_method_display_name (uri->method_string);
