@@ -42,7 +42,8 @@ typedef enum {
  * Returns TRUE if it succeeds, FALSE if it fails.
  */
 gboolean         nautilus_link_local_create                      (const char       *directory_uri,
-								  const char       *name,
+								  const char       *file_name,
+								  const char       *display_name,
 								  const char       *image,
 								  const char       *target_uri,
 								  const GdkPoint   *point,
